@@ -1,5 +1,5 @@
-from indicoio.utils.api import api_handler
-from indicoio.utils.decorators import detect_batch_decorator
+from ..utils.api import api_handler
+from ..utils.decorators import detect_batch_decorator
 
 
 @detect_batch_decorator
@@ -23,4 +23,6 @@ def personality(text, cloud=None, batch=False, api_key=None, version=None, **kwa
     'Openness', and 'Agreeableness' score (a float between 0 and 1) in a dictionary.
     """
     url_params = {"batch": batch, "api_key": api_key, "version": version}
-    return api_handler(text, cloud=cloud, api="personality", url_params=url_params, **kwargs)
+    return api_handler(
+        text, cloud=cloud, api="personality", url_params=url_params, **kwargs
+    )
