@@ -116,7 +116,14 @@ def standardize_input_data(data):
 
 
 def api_handler(
-    input_data, cloud, api, url_params=None, batch_size=None, job_options=None, **kwargs
+    input_data,
+    cloud,
+    api,
+    url_params=None,
+    batch_size=None,
+    job_options=None,
+    host=None,
+    **kwargs
 ):
     """
     Sends finalized request data to ML server and receives response.
@@ -130,7 +137,7 @@ def api_handler(
     input_data = standardize_input_data(input_data)
 
     cloud = cloud or config.cloud
-    host = "%s.indico.domains" % cloud if cloud else config.host
+    host = host or ("%s.indico.domains" % cloud if cloud else config.host)
 
     # LOCAL DEPLOYMENTS
     url_protocol = config.url_protocol
@@ -230,7 +237,7 @@ def send_request(input_data, api, url, headers, kwargs):
 
     json_data = json.dumps(data)
 
-    response = requests.post(url, data=json_data, headers=headers)
+    response = requests.post(url, data=json_data, headers=headers, verify=config.verify)
     warning = response.headers.get("x-warning")
     if warning:
         warnings.warn(warning)
